==> haskell-mmark-0.0.7.6-337.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-mmark.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 mmark
version:              0.0.7.6
visibility:           public
id:                   mmark-0.0.7.6-5pjQPOX7BlV9LpnbxuWbW1
key:                  mmark-0.0.7.6-5pjQPOX7BlV9LpnbxuWbW1
license:              BSD-3-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:               Mark Karpov <markkarpov92@gmail.com>
homepage:             https://github.com/mmark-md/mmark
synopsis:             Strict markdown processor for writers
description:          Strict markdown processor for writers.
category:             Text
abi:                  ef888ab1477e254031ab9267664434bf
exposed:              True
exposed-modules:      Text.MMark Text.MMark.Extension
hidden-modules:
    Text.MMark.Parser Text.MMark.Parser.Internal
    Text.MMark.Parser.Internal.Type Text.MMark.Render Text.MMark.Trans
    Text.MMark.Type Text.MMark.Util

import-dirs:          /usr/lib/ghc-9.6.6/site-local/mmark-0.0.7.6
library-dirs:         /usr/lib/ghc-9.6.6/site-local/mmark-0.0.7.6
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/mmark-0.0.7.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mmark
hs-libraries:         HSmmark-0.0.7.6-5pjQPOX7BlV9LpnbxuWbW1
depends:
    aeson-2.1.2.1-GojnAvr1Jep10WUNi5H1Pi base-4.18.2.1
    case-insensitive-1.2.1.0-3fPl2hvou1nDiCO1iE2i5z containers-0.6.7
    deepseq-1.4.8.1 dlist-1.0-B7D1vsARFiIHVaGk5CGbYO
    email-validate-2.3.2.21-7k0Inpx6EuzEKmxIRZFsX3
    foldl-1.4.18-DnwxI7jar0n9jaHnbNBdzr
    hashable-1.4.7.0-DKTv0aQgcZmBEMi2BPTV4Z
    html-entity-map-0.1.0.0-FL390C27So6xDXTeE134j
    lucid-2.11.20250303-mIfSyYQWD8L0pbvgCqca8
    megaparsec-9.7.0-Fzm61TdpQu7Cpey7aoa8J9
    microlens-0.4.14.0-IP2Uuhm3qTnDhkfYobH8B3
    microlens-th-0.4.3.17-IPbJLKFzpBF3M0tXA6bBdw
    modern-uri-0.3.6.1-IwjiwRk8dF03FTPer57pKX mtl-2.3.1
    parser-combinators-1.3.0-20UTEUZ5CKDJdRu747ID48 text-2.0.2
    text-metrics-0.3.3-EtdayY9JRqPIHrPm1Benmg
    unordered-containers-0.2.20.1-50qrTxmoJy9AxZ7OdMnycu
    yaml-0.11.11.2-GyIObvMByN0941lpfsiwCu

haddock-interfaces:   /usr/share/doc/haskell-mmark/html/mmark.haddock
haddock-html:         /usr/share/doc/haskell-mmark/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mmark-0.0.7.6-338-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-mmark.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 mmark
version:              0.0.7.6
visibility:           public
id:                   mmark-0.0.7.6-I3gmhliLEjIA9qAJLEObvW
key:                  mmark-0.0.7.6-I3gmhliLEjIA9qAJLEObvW
license:              BSD-3-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:               Mark Karpov <markkarpov92@gmail.com>
homepage:             https://github.com/mmark-md/mmark
synopsis:             Strict markdown processor for writers
description:          Strict markdown processor for writers.
category:             Text
abi:                  d764a031d3ee66a237953927678ada17
exposed:              True
exposed-modules:      Text.MMark Text.MMark.Extension
hidden-modules:
    Text.MMark.Parser Text.MMark.Parser.Internal
    Text.MMark.Parser.Internal.Type Text.MMark.Render Text.MMark.Trans
    Text.MMark.Type Text.MMark.Util

import-dirs:          /usr/lib/ghc-9.6.6/site-local/mmark-0.0.7.6
library-dirs:         /usr/lib/ghc-9.6.6/site-local/mmark-0.0.7.6
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/mmark-0.0.7.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mmark
hs-libraries:         HSmmark-0.0.7.6-I3gmhliLEjIA9qAJLEObvW
depends:
    aeson-2.1.2.1-CpIoOLI7lIpJkSqSOmDN9y base-4.18.2.1
    case-insensitive-1.2.1.0-KNymwxzPyypAOJSQGx0ioI containers-0.6.7
    deepseq-1.4.8.1 dlist-1.0-B7D1vsARFiIHVaGk5CGbYO
    email-validate-2.3.2.21-6BQ3rNhF1qq9n1JEwG6kxE
    foldl-1.4.18-c4zLrEmO0CGifNSU6CYor
    hashable-1.4.7.0-1GSULm1uRgQBgX6mu6tvYD
    html-entity-map-0.1.0.0-DXFxNbP4Xar2JWuKDcz4q7
    lucid-2.11.20250303-2DU0tzsivWAatyw5ZOVax
    megaparsec-9.7.0-CJUMznUvVaqA9LkZfHNyDE
    microlens-0.4.14.0-IP2Uuhm3qTnDhkfYobH8B3
    microlens-th-0.4.3.17-IPbJLKFzpBF3M0tXA6bBdw
    modern-uri-0.3.6.1-Fr6OaKthQTjHVJ2Unps2DR mtl-2.3.1
    parser-combinators-1.3.0-20UTEUZ5CKDJdRu747ID48 text-2.0.2
    text-metrics-0.3.3-542FvMYuyImLLT35eUtKmy
    unordered-containers-0.2.20.1-L0jiELAFLwP1g4FZscm3B5
    yaml-0.11.11.2-HJgRwey6BMIIq0hOFQKRBa

haddock-interfaces:   /usr/share/doc/haskell-mmark/html/mmark.haddock
haddock-html:         /usr/share/doc/haskell-mmark/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
